@@ -1,6 +1,6 @@
 package OpenInteract::FullText;
 
-# $Id: FullText.pm,v 1.9 2001/10/01 17:13:51 lachoy Exp $
+# $Id: FullText.pm,v 1.11 2001/10/29 14:29:22 lachoy Exp $
 
 use strict;
 use Lingua::Stem ();
@@ -11,7 +11,7 @@ BEGIN {
     eval { require OpenInteract::FullTextIterator };
 }
 
-$OpenInteract::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract::FullText::ISA     = ();
 
 use constant COLUMN_GROUP    => 'listing';
@@ -144,7 +144,7 @@ sub _fulltext_object_listing {
 # Add the various group checking/validating methods 
 # to the subclass and send it on up the line 
 
-sub ruleset_add {
+sub ruleset_factory {
     my ( $class, $rs_table ) = @_;
     my $obj_class = ref $class || $class;
     push @{ $rs_table->{post_save_action} }, \&reindex_object;
@@ -162,16 +162,16 @@ sub reindex_object {
     my ( $self, $p ) = @_;
     my $R = OpenInteract::Request->instance;
     $R->DEBUG && $R->scrib( 1, "Trying to index ", ref $self, " (", $self->id, ")" );
-    my $indexable = $self->_indexable_object_text;
-    $R->DEBUG && $R->scrib( 2, "Indexable text: ", $indexable );
-    my $wc = $self->_tokenize( $indexable );
-    $R->DEBUG && $R->scrib( 2, "Found the following tokens:", Dumper( $wc ) );
+    my $indexable = _indexable_object_text( $self, $p );
+    $R->DEBUG && $R->scrib( 1, "Indexable text: ", $$indexable );
+    my $wc = _tokenize( $self, $indexable );
+    $R->DEBUG && $R->scrib( 1, "Found the following tokens:", Dumper( $wc ) );
  
     # In the 'real world', we'd start a transaction here...
 
-    my $remove_rv = $self->remove_object_from_index;
+    my $remove_rv = remove_object_from_index( $self );
     $R->DEBUG && $R->scrib( 1, "Results of removal: ($remove_rv)" );
-    my $store_rv  = $self->_store_terms( $wc ) if ( keys %{ $wc } );
+    my $store_rv  = _store_terms( $self, $wc ) if ( keys %{ $wc } );
 
     # ... and then commit it here if everything went ok
 
@@ -200,30 +200,47 @@ sub remove_object_from_index {
 
 # Get the fields that should be indexed and join the values together
 # with a space (easy), since we're just going to index all the text as
-# one big field
+# one big field. Returns a scalar REF.
 
 sub _indexable_object_text {
-    my ( $self ) = @_;
+    my ( $self, $p ) = @_;
+    $p ||= {};
     my $R = OpenInteract::Request->instance;
-    my $field_list = $self->CONFIG->{fulltext_field};
+
+    my $field_list = $p->{fulltext_field} || $self->CONFIG->{fulltext_field};
     unless ( ref $field_list eq 'ARRAY' ) {
         $R->scrib( 0, "Cannot index object text -- no fields presented in config file." );
         return undef;
     }
-    return join ' ', map { $self->{$_} } @{ $field_list };
+    my ( $indexable );
+    foreach my $field ( @{ $field_list } ) {
+        if ( ! ref $self->{ $field } ) {
+            $indexable = join( ' ', $indexable, $self->{ $field } );
+        }
+        elsif ( ref $self->{ $field } eq 'SCALAR' ) {
+            $indexable = join( ' ', $indexable, $$self->{ $field } );
+        }
+
+        else {
+            my $fh = $self->{ $field };
+            $indexable = join( ' ', $indexable, <$fh> );
+        }
+    }
+    return \$indexable;
 }
 
 
 # Break up the text into tokens -- stemmed using Lingua::Stem and
 # counted for occurrences. Remove the words that are too long, too
-# short and those that are found in our STOPWORDS listing.
+# short and those that are found in our STOPWORDS listing. Takes a
+# scalar REF as an argument.
 
 sub _tokenize {
-    my ( $self, $text ) = @_;
-    $text =~ tr/A-Z/a-z/;  # lowercase
+    my ( $self, $text_ref ) = @_;
+    $$text_ref =~ tr/A-Z/a-z/;  # lowercase
     my %words = ();
-    map { $words{ $_ }++ } map { Lingua::Stem::stem( $_ )->[0] } ( $text =~ /\w+/g );
-    map { delete $words{ $_ } }  
+    map { $words{ $_ }++ } map { Lingua::Stem::stem( $_ )->[0] } ( $$text_ref =~ /\w+/g );
+    map { delete $words{ $_ } }
         grep { length $_ < MIN_WORD_LENGTH || length $_ > MAX_WORD_LENGTH }
         keys %words;
     map { delete $words{ $_ } } keys %STOPWORDS;
@@ -521,10 +538,10 @@ break the text into words, then we lower case each word, then we
 
 (From: http://ollie.dcccd.edu/library/Module2/Books/concepts.htm)
 
-We use the L<Lingua::Stem> module for this, which implements the
-I<Porter algorithm> for stemming, as do most implementations,
-apparently. (This is something that I<OpenInteract::FullText> treats as a
-black box itself :)
+We use the L<Lingua::Stem|Lingua::Stem> module for this, which
+implements the I<Porter algorithm> for stemming, as do most
+implementations, apparently. (This is something that this class treats
+as a black box itself :)
 
 Parameters:
 
