@@ -1,6 +1,6 @@
 package OpenInteract::Handler::BasicPage;
 
-# $Id: BasicPage.pm,v 1.15 2001/10/12 16:04:14 lachoy Exp $
+# $Id: BasicPage.pm,v 1.16 2001/10/17 12:02:13 lachoy Exp $
 
 use strict;
 use SPOPS::Secure  qw( :level );
@@ -9,7 +9,7 @@ use Data::Dumper   qw( Dumper );
 use File::Basename qw();
 
 @OpenInteract::Handler::BasicPage::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure  );
-$OpenInteract::Handler::BasicPage::VERSION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::BasicPage::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::BasicPage::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::BasicPage::default_method    = 'listing';
@@ -22,7 +22,6 @@ $OpenInteract::Handler::BasicPage::default_method    = 'listing';
 
 
 use constant MAIN_SCRIPT     => '/BasicPage';
-use constant NO_PARSE_STATUS => 'no_parse';
 
 # Use this to mark the beginning and end of the "good" content in a
 # page in the filesystem; this allows you to use an HTML editor to
@@ -44,53 +43,6 @@ my $PAGE_SEPARATOR = '<!--PAGE-->';
 my $DEFAULT_EXPIRE = 60 * 60 * 24 * 7 * 52;
 
 
-# Overrides entry in OpenInteract::Handler::GenericDispatcher
-
-sub _get_task {
-    my ( $class ) = @_;
-    my $R = OpenInteract::Request->instance;
-    return 'show'  if ( $R->{path}{full}->[0] ne 'BasicPage' );
-    return lc shift @{ $R->{path}{current} }
-                || $OpenInteract::Handler::BasicPage::default_method;
-}
-
-
-
-# Retrieve all directories, expanding the one we were asked to (if at
-# all). Note that these are just the objects in the database.
-
-sub listing {
-    my ( $class, $p ) = @_;
-    my $R = OpenInteract::Request->instance;
-    my $selected_dir = $R->apache->param( 'selected_dir' );
-    my $select_all = ( $selected_dir eq 'EXPANDALL' );
-    my $params = { main_script  => MAIN_SCRIPT,
-                   selected_dir => $selected_dir,
-                   error_msg    => $p->{error_msg} };
-    $params->{dir_list} = eval { $R->static_page->list_directories() };
-    if ( $@ ) {
-        OpenIntereact::Error->set( SPOPS::Error->get );
-        $R->throw( { code => 403 } );
-        $params->{dir_list} = [];
-    }
-
-    # Store the pages found using the directory as a key pointing to a
-    # listref of files it contains
-
-    if ( $selected_dir ) {
-        $params->{children_files} = $R->static_page->fetch_iterator({
-                                               column_group => 'listing',
-                                               where        => 'directory = ?',
-                                               value        => [ $selected_dir ] });
-    }
-
-    $R->{page}{title} = 'Listing of Documents';
-    return $R->template->handler( {}, $params,
-                                  { db      => 'static_dir_listing',
-                                    package => 'static_page' } );
-}
-
-
 sub show {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
@@ -140,12 +92,12 @@ sub show {
         };
         my $error_type = $@;
 
-        unless ( $page_info or $do_edit ) {
+        unless ( $page or $do_edit ) {
             $R->DEBUG && $R->scrib( 1, "Creating new page or empty page info. Error type: ($error_type)" );
 
             # We have to force the content-type here because the user
             # might have requested a file that actually exists in the
-            # filesystem and which Apache has already mapped a
+            # filesystem for which Apache has already mapped a
             # content-type. You'll know when this happens because
             # you'll be prompted to d/l the file or a plugin (like
             # Acrobat Reader) will try to display it, but the *actual*
@@ -154,16 +106,22 @@ sub show {
             $R->{page}{content_type} = 'text/html';
 
             if ( $error_type =~ /^security/ ) {
-                return "<h2>Access Forbidden</h2>" .
-                       "<p>You do not have access rights to view this page. " .
-                       "Please e-mail an administrator if you feel you have received this message in error.</p>";
+                my $admin_email = $R->CONFIG->{mail}{admin_email};
+                return <<FORBID;
+<h2>Access Forbidden</h2>
+<p>You do not have access rights to view this page.  Please e-mail the
+administrator at <a href="mailto:$admin_email">$admin_email</a> if you
+feel you have received this message in error.</p>
+FORBID
             }
             elsif ( $error_type =~ /^access/ ) {
-                return "<h2>Cannot Access</h2>" .
-                       "<p>Failure accessing page.</p>";
+                return "<h2>Cannot Access</h2><p>Failure accessing page.</p>";
             }
-            return "<h2>Page Not Found</h2>" .
-                   "<p>Could not find page with location: (<tt>$location</tt>). Error logged.</p>";
+            return <<NOTFOUND;
+<h2>Page Not Found</h2>
+<p>Could not find page with location:
+(<tt>$location</tt>). Did you mistype the address?</p>
+NOTFOUND
         }
     }
 
@@ -568,79 +526,6 @@ PCOUNT
 }
 
 
-sub _add_object_boxes {
-    my ( $class, $page_info, $p ) = @_;
-    my $R = OpenInteract::Request->instance;
-
-  # Do the related items
-#   push @{ $R->{boxes} }, { name => 'relateditems', params => { object => $page } };
-
-  # If this page has specified any boxes, push them onto the stack
-  # unless they start with a '-', in which case set that name aside
-  # so we can go through all of the boxes and remove it.
- 
-    my %box_remove = ();
-    if ( $page_info->{boxes} ) {
-        my @boxes = split /\s+/, $page_info->{boxes};
-        foreach my $box_name ( @boxes ) {
-            next if ( $box_name =~ /^\s*$/ );
-            $R->scrib( 1, "Adding box name ($box_name) from page definition" );
-            if ( $box_name =~ s/^\-// ) {
-                $box_remove{ $box_name }++;
-            }
-            else {
-                push @{ $R->{boxes} }, $box_name;
-            }
-        }
-
-        # Go through ALL the boxes and do a removal if necessary
-        # (TODO: we should move this processing to base_box)
-
-        my @box_keep = ();
-        foreach my $box_info ( @{ $R->{boxes} } ) {
-            next if ( ref $box_info and $box_remove{ $box_info->{name} } );
-            next if ( ! ref $box_info and $box_remove{ $box_info } );
-            push @box_keep, $box_info;
-        }
-        $R->{boxes} = \@box_keep;
-    }
-
-    # If this person has WRITE access to the module, give them a box
-    # so they can edit/remove this document
-
-    if ( $p->{level} >= SEC_LEVEL_WRITE ) {
-        push @{ $R->{boxes} }, { name   => 'edit_document_box',
-                                 params => { location => $page_info->{location} } },
-                               { name   => 'object_modify_box',
-                                 params => { object => $page_info->{_object} } };
-    }
-    return undef;
-}
-
-
-sub _check_active_date {
-    my ( $class, $page_info ) = @_;
-    my $R = OpenInteract::Request->instance;
-
-    return 1 unless ( $page_info->{active_on} );
-    my ( $active_days, $now_days, $expire_days );
-    eval {
-        $active_days = Date_to_Days( split '-', $page_info->{active_on} );
-        $now_days    = Date_to_Days( split '-', SPOPS::Utility->now( { format => '%Y-%m-%d' } ) );
-        $expire_days = Date_to_Days( split '-', $page_info->{expires_on} );
-    };
-    if ( $@ ) {
-        $R->scrib( 0, "Problem while trying to evaluate days! Error: $@" );
-        return 1;
-    }
- 
-    $R->DEBUG && $R->scrib( 1, "Active on: $page_info->{active_on}; Expires on: $page_info->{expires_on}\n",
-                               "Active: $active_days; Now: $now_days; Expire: $expire_days" );
-    return undef if ( $now_days < $active_days );
-    return undef if ( $now_days > $expire_days );
-    $R->DEBUG && $R->scrib( 1, "Page is active since $active_days < $now_days < $expire_days." );
-    return 1;
-}
 
 1;
 
