@@ -1,13 +1,13 @@
 package OpenInteract::Handler::Component;
 
-# $Id: Component.pm,v 1.7 2001/07/13 14:44:59 lachoy Exp $
+# $Id: Component.pm,v 1.10 2001/09/27 01:06:23 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 
 @OpenInteract::Handler::Component::ISA     = ();
-$OpenInteract::Handler::Component::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Component::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Component::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Component::default_method    = 'handler';
@@ -27,30 +27,44 @@ sub handler {
     }
 
     my @modified_action = $class->_modify_action( $p->{name}  );
-    my $action_info = $R->lookup_action([ $p->{name}, @modified_action ], 
+    my $action_info = $R->lookup_action([ $p->{name}, @modified_action ],
                                         { return => 'info', skip_default => 1 });
 
     # If we don't find a action, assume that we're simply calling a
-    # template with the specified name
+    # template with the specified name; note that if we pass in
+    # 'template' (like for boxes) that are in the 'pkg::template'
+    # format we set the 'package' key below
 
     unless ( scalar keys %{ $action_info } ) {
-        $R->DEBUG && $R->scrib( 1, "No action info found; using name ($p->{name}) as template" );
-        $action_info->{template} = $action_info->{name} = $p->{name};
-        $action_info->{package}  = $p->{package};
+        $R->DEBUG && $R->scrib( 1, "No action info returned; just using template name." );
+        $action_info->{name}       = $p->{name};
+        $action_info->{template}   = $p->{template} || $action_info->{name};
+        $action_info->{package}    = $p->{package};
+        $R->DEBUG && $R->scrib( 1, "Using template ($action_info->{template})",
+                                   "(package if needed: $action_info->{package})" );
     }
-    unless ( $action_info->{template} or 
+
+    unless ( $action_info->{template} or
              $action_info->{class} or
              ref $action_info->{code} ) {
-        $R->DEBUG && $R->scrib( 1, "No action info found; using name ($p->{name}) as template" );
+        $R->DEBUG && $R->scrib( 1, "No relevant action info; using name ($p->{name}) as template" );
         $action_info->{template} = $p->{name};
     }
     $R->DEBUG && $R->scrib( 2, "Action_info:\n", Dumper( $action_info ) );
 
-    # If the template is a 'pkg::template' format, set the items properly
+    # If the template is not in 'pkg::template' format, set it up so
+    # Most of this confusing stuff is for backward compatibility; in a
+    # few revs we'll take it out
 
-    if ( $action_info->{template} =~ /^(.*)?::(.*)$/ ) {
-        $action_info->{package}  = $1;
-        $action_info->{template} = $2;
+    if ( $action_info->{template} ) {
+        if ( $action_info->{template} =~ /^(\w+)::(\w+)$/ ) {
+            $action_info->{template_name} = $action_info->{template};
+            $action_info->{package}       = $1;
+            $action_info->{template}      = $2;
+        }
+        else {
+            $action_info->{template_name} = join( '::', $action_info->{package}, $action_info->{template} );
+        }
     }
 
     $action_info->{package} ||= $action_info->{package_name};
@@ -60,23 +74,22 @@ sub handler {
     # whatever was passed in.
 
     my $params = ( ref $p->{params} ) ? $p->{params} : $p;
-    $R->DEBUG && $R->scrib( 2, "Parameters being passed to component:\n", Dumper( $params ) );
+    $R->DEBUG && $R->scrib( 3, "Parameters being passed to component:\n", Dumper( $params ) );
 
     # Now that we have information for the component, go ahead and
     # process it -- output goes to $html. Note that if no component
-    # information is specified the 'template' key in $action_info should
-    # have been specified. If no template is found then
+    # information is specified the 'template_name' key in $action_info
+    # should have been specified. If no template is found then
     # OpenInteract::Template will give us an error message in $html
 
-    my ( $html );    
+    my ( $html );
 
     # Process the standalone template
 
-    if ( $action_info->{template} ) {
-        $R->DEBUG && $R->scrib( 1, "Generic template action with ($action_info->{template})" );
-        $html = eval { $R->template->handler( {}, $params, 
-                                              { db      => $action_info->{template}, 
-                                                package => $action_info->{package} }) };
+    if ( $action_info->{template_name} ) {
+        $R->DEBUG && $R->scrib( 1, "Generic template action with ($action_info->{template_name})" );
+        $html = eval { $R->template->handler( {}, $params,
+                                              { name => $action_info->{template_name} } ) };
     }
 
     # Run the code reference 
@@ -128,11 +141,11 @@ sub _check_security {
         $required_level = $all_levels{ $action_info->{method} } || NOTFOUND_SECURITY;
     }
     $R->DEBUG && $R->scrib( 1, "Checking security for component." );
-    my $current_level   = eval { $R->secure->check_security({ 
+    my $current_level   = eval { $R->secure->check_security({
                                           security_object_class => $R->security_object,
                                           db        => $R->db,
                                           user      => $R->{auth}->{user},
-                                          class     => $action_info->{class}, 
+                                          class     => $action_info->{class},
                                           object_id => '0' }) };
     $current_level ||= SEC_LEVEL_WRITE;
     $R->DEBUG && $R->scrib( 1, "Target security: ($required_level); Actual: ($current_level)" );
@@ -145,11 +158,11 @@ sub _check_security {
 # action table
 
 sub _modify_action {
-  my ( $class, $action ) = @_;
-  my @modified = ( lc $action );
-  $action =~ s/[\_\-\s]//g;
-  push @modified, $action;
-  return @modified;
+    my ( $class, $action ) = @_;
+    my @modified = ( lc $action );
+    $action =~ s/[\_\-\s]//g;
+    push @modified, $action;
+    return @modified;
 }
 
 1;
