@@ -1,6 +1,6 @@
 package OpenInteract::ResultsManage;
 
-# $Id: ResultsManage.pm,v 1.9 2001/10/11 03:17:27 lachoy Exp $
+# $Id: ResultsManage.pm,v 1.10 2001/10/31 22:00:09 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
@@ -8,7 +8,7 @@ use IO::File;
 use SPOPS::Utility;
 
 @OpenInteract::ResultsManage::ISA     = ();
-$OpenInteract::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 use constant FILENAME_WIDTH => 20;
 
@@ -48,6 +48,18 @@ sub clear {
 sub save {
     my ( $self, $to_save, $p ) = @_;
     my $R = OpenInteract::Request->instance;
+
+    my ( $is_empty );
+
+    $is_empty++ unless( $to_save );
+    $is_empty++ if ( ref $to_save eq 'ARRAY' and ! scalar @{ $to_save } );
+    $is_empty++ if ( UNIVERSAL::isa( $to_save, 'SPOPS::Iterator' ) and ! $to_save->has_next );
+
+    if ( $is_empty ) {
+        $R->scrib( 0, "Bailing out of saving search results -- nothing to save!" );
+        return undef;
+    }
+
     $R->DEBUG && $R->scrib( 1, "Trying to save search results." );
 
     my %params = ( force_mixed => $p->{force_mixed},
