@@ -1,6 +1,6 @@
 package OpenInteract::SPOPS;
 
-# $Id: SPOPS.pm,v 1.13 2001/08/22 04:48:50 lachoy Exp $
+# $Id: SPOPS.pm,v 1.19 2001/11/26 13:18:32 lachoy Exp $
 
 use strict;
 use Data::Dumper    qw( Dumper );
@@ -8,7 +8,7 @@ use Digest::MD5     qw( md5_hex );
 use HTML::Entities  ();
 
 @OpenInteract::SPOPS::ISA     = ();
-$OpenInteract::SPOPS::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::SPOPS::VERSION = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
 
 use constant OBJECT_KEY_TABLE => 'object_keys';
 
@@ -17,7 +17,7 @@ use constant OBJECT_KEY_TABLE => 'object_keys';
 # RULESET
 ########################################
 
-sub ruleset_add {
+sub ruleset_factory {
     my ( $class, $rs_table ) = @_;
     push @{ $rs_table->{post_save_action} }, \&save_object_key;
     return __PACKAGE__;
@@ -30,7 +30,7 @@ sub save_object_key {
     my ( $self, $p ) = @_;
 
     # Don't create an object key if we're explicitly told not to
-    return 1 if ( $self->CONFIG->{skip_object_key} );
+    return 1 if ( $self->CONFIG->{skip_object_key} || $p->{skip_object_key} );
 
     $p ||= {};
     my $obj_key = $self->fetch_object_key;
@@ -65,7 +65,7 @@ sub generate_object_key {
 sub fetch_object_key {
     my ( $self, $p ) = @_;
     $p ||= {};
-    my $row = $self->db_select({ %{ $p }, 
+    my $row = $self->db_select({ %{ $p },
                                  from   => OBJECT_KEY_TABLE,
                                  select => [ 'object_key' ],
                                  where  => 'class = ? AND object_id = ?',
@@ -81,9 +81,9 @@ sub fetch_object_key {
 sub fetch_object_info_by_key {
     my ( $class, $key, $p ) = @_;
     $p ||= {};
-    $p->{db} ||= $class->global_db_handle;
+    $p->{db} ||= $class->global_datasource_handle;
     die "Cannot retrieve object info without key!" unless ( $key );
-    my $row = SPOPS::SQLInterface->db_select({ %{ $p }, 
+    my $row = SPOPS::SQLInterface->db_select({ %{ $p },
                                                from   => OBJECT_KEY_TABLE,
                                                select => [ 'class', 'object_id' ],
                                                where  => 'object_key = ?',
@@ -113,12 +113,12 @@ sub fetch_object_by_key {
 
 sub log_action {
     my ( $self, $action, $id ) = @_;
-    return 1   unless ( $self->CONFIG->{track}->{ $action } );
+    return 1   unless ( $self->CONFIG->{track}{ $action } );
     return $self->log_action_enter( $action, $id );
 }
 
 
-# Log the object, the action (create, update, remove), who did 
+# Log the object, the action (create, update, remove), who did
 # the action and when it was done.
 #
 # Note that you can pass the uid in directly to override the current user
@@ -126,18 +126,21 @@ sub log_action {
 sub log_action_enter {
     my ( $self, $action, $id, $uid ) = @_;
     my $R = OpenInteract::Request->instance;
-    $uid ||= ( ref $R->{auth}->{user} ) ? $R->{auth}->{user}->{user_id} : 0;
+    $uid ||= ( ref $R->{auth}{user} ) ? $R->{auth}{user}{user_id} : 0;
     my $now = SPOPS::Utility->now;
     my $class = ref $self || $self;
-    my $log_msg = $R->apache->param( '_log_message' );
+    my ( $log_msg );
+    if ( my $apr = $R->apache ) {
+        $log_msg = $apr->param( '_log_message' );
+    }
     $R->DEBUG && $R->scrib( 1, "Entering action $action to $class ($id) by $uid on $now" );
-    eval { $self->db_insert({ db    => $R->db, 
-                              table => 'object_track', 
+    eval { $self->db_insert({ db    => $R->db,
+                              table => 'object_track',
                               field => [ qw/ class object_id action action_by action_on notes / ],
                               value => [ $class, $id, $action, $uid, $now, $log_msg ] } ); };
     if ( $@ ) {
         $R->scrib( 0, "Log entry failed: $SPOPS::Error::system_msg" );
-        OpenInteract::Error->set( SPOPS::Error->get ); 
+        OpenInteract::Error->set( SPOPS::Error->get );
         $OpenInteract::Error::user_msg = "Cannot log object action: $action";
         $OpenInteract::Error::notes    = "Object: $class ($id) by $uid on $now";
         $R->throw({ code => 302 });
@@ -156,8 +159,8 @@ sub fetch_creator {
     # Bail if it's not an already-existing object
     return undef  unless ( ref $self and $self->id );
     my $R = OpenInteract::Request->instance;
-    my $data = eval { $self->db_select({ 
-                               db     => $R->db, 
+    my $data = eval { $self->db_select({
+                               db     => $R->db,
                                select => [ 'action_by' ],
                                from   => [ 'object_track' ],
                                where  => 'class = ? AND object_id = ? and action = ?',
@@ -165,7 +168,7 @@ sub fetch_creator {
                                return => 'single-list' }) };
     if ( $@ ) {
         $OpenInteract::Error::user_msg = 'Cannot retrieve object creator(s)';
-        $OpenInteract::Error::extra    = { class     => ref $self, 
+        $OpenInteract::Error::extra    = { class     => ref $self,
                                            object_id => $self->id };
         $R->throw( { code => 306 } );
         return undef;
@@ -181,12 +184,12 @@ sub fetch_creator {
 sub is_creator {
     my ( $self, $uid ) = @_;
     my $R = OpenInteract::Request->instance;
-    $uid ||= $R->{auth}->{user}->{user_id};
+    $uid ||= $R->{auth}{user}{user_id};
     return undef unless ( $uid );
 
     # the great and powerful superuser sees all
 
-    return 1     if ( $uid eq $R->CONFIG->{default_objects}->{superuser} );
+    return 1     if ( $uid eq $R->CONFIG->{default_objects}{superuser} );
 
     my $creator_list = eval { $self->fetch_creator } || [];
     foreach my $creator ( @{ $creator_list } ) {
@@ -196,8 +199,8 @@ sub is_creator {
 }
 
 
-# Retrieve an arrayref of arrayrefs where item 0 is the uid 
-# of the user who last did the update and item 1 is the 
+# Retrieve an arrayref of arrayrefs where item 0 is the uid
+# of the user who last did the update and item 1 is the
 # date of the update
 
 sub fetch_updates {
@@ -217,7 +220,7 @@ sub fetch_updates {
                                order  => 'action_on DESC', return => $return } ); };
     if ( $@ ) {
         $OpenInteract::Error::user_msg = 'Cannot retrieve object updates';
-        $OpenInteract::Error::extra    = { class     => ref $self, 
+        $OpenInteract::Error::extra    = { class     => ref $self,
                                            object_id => $self->id };
         $R->throw( { code => 306 } );
         return undef;
@@ -258,30 +261,8 @@ sub global_secure_class          { return OpenInteract::Request->instance->secur
 sub global_security_object_class { return OpenInteract::Request->instance->security        }
 sub global_user_class            { return OpenInteract::Request->user                      }
 sub global_group_class           { return OpenInteract::Request->group                     }
-sub global_user_current          { return OpenInteract::Request->instance->{auth}->{user}  }
-sub global_group_current         { return OpenInteract::Request->instance->{auth}->{group} }
-
-
-########################################
-# HTML ENCODE/DECODE (keep?)
-########################################
-
-# Use this to translate from
-# <font size="-1"...
-#   to
-# &lt;font size=&quot;-1&quot...
-# Params: 0: class; 1: text
-
-sub html_encode { return HTML::Entities::encode( $_[1] ); }
-
-
-# Use this to translate from
-# &lt;font size=&quot;-1&quot...
-#   to
-# <font size="-1"...
-# Params: 0: class; 1: text
-
-sub html_decode { return HTML::Entities::decode( $_[1] ); }
+sub global_user_current          { return OpenInteract::Request->instance->{auth}{user}  }
+sub global_group_current         { return OpenInteract::Request->instance->{auth}{group} }
 
 
 ########################################
@@ -296,31 +277,42 @@ sub notify {
     my $R = OpenInteract::Request->instance;
     $p->{object} ||= [];
 
-    # If we weren't given any objects and we were called by 
+    # If we weren't given any objects and we were called by
     # a class instead of an object
 
     return undef unless ( ref $item or scalar @{ $p->{object} } );
 
-    # If we were just called by an object, make it our message 
+    # If we were just called by an object, make it our message
 
     push @{ $p->{object} }, $item  unless ( scalar @{ $p->{object} } );
     my $num_objects = scalar @{ $p->{object} };
     my $subject = $p->{subject} || "Object notification: $num_objects objects in mail";
     my $separator = '=' x 25;
-    my $msg = ( $p->{notes} ) ? join( "\n", 'Notes', "$separator$p->{notes}", $separator, "\n" ) : '';
+    my $msg = ( $p->{notes} ) ?
+                join( "\n", 'Notes', "$separator$p->{notes}", $separator, "\n" ) : '';
     foreach my $obj ( @{ $p->{object} } ) {
         my $info = $obj->object_description;
         my $object_url = join( '', 'http://', $R->{server_name}, $info->{url} );
-        $msg .= "Begin $p->{type} object\n$separator\n" .
-                $obj->as_string . "\n" .
-                "View this object at: $object_url\n" .
-                "\n$separator\nEnd $p->{type} object\n\n\n";
+        $msg .= <<OBJECT;
+Begin $info->{name} object
+$separator
+@{[ $obj->as_string ]}
+
+View this object at: $object_url
+$separator
+End $p->{name} object
+
+OBJECT
     }
-    eval { OpenInteract::Utility->send_email({ 
-                                    to      => $p->{email},
-                                    from    => $R->CONFIG->{admin_email},
-                                    subject => $subject,
-                                    message => $msg }) };
+    my $from_email = $p->{email_from} ||
+                     $R->CONFIG->{mail}{admin_email} ||
+                     $R->CONFIG->{admin_email};
+    eval {
+        OpenInteract::Utility->send_email({ to      => $p->{email},
+                                            from    => $from_email,
+                                            subject => $subject,
+                                            message => $msg });
+    };
     if ( $@ ) {
         $R->throw({ code => 203 });
         return undef;
@@ -391,7 +383,7 @@ B<log_action_enter( $action, $id )>
 
 Makes an entry into the 'object_track' table, which logs all object
 creations, updates and deletions. We do not note the content that
-changes, but we do note who did the action and when it was done. 
+changes, but we do note who did the action and when it was done.
 
 Parameters:
 
@@ -496,45 +488,46 @@ simple property -> value listing. You can override this with
 information in your class configuration which specifies the fields you
 want to use in the listing along with associated labels.
 
-B<html_encode( $text )>
-
 Parameters:
 
 =over 4
 
 =item *
 
-B<text> ($)
+B<email> ($)
 
-Text to encode.
-
-=back
-
-B<Returns>: escaped version of $text (e.g., the character '"' will be
-replaced by &quot;)
-
-B<html_decode( $text )>
-
-Parameters:
-
-=over 4
+Address to which we should send the notification.
 
 =item *
 
-B<text> ($)
+B<email_from> ($) (optional)
 
-Text to decode.
+Address from which the email should be sent. If not specified this
+defaults to the 'admin_email' setting in your server configuration
+(under 'mail').
+
+=item *
+
+B<subject> ($) (optional)
+
+Subject of email. If not specified the subject will be 'Object
+notification # objects in mail'.
+
+=item *
+
+B<object> (\@) (optional if called from an object)
+
+If not called from an object, this should be an arrayref of objects to
+notify someone about.
+
+=item *
+
+B<notes> ($) (optional)
+
+Notes that lead off an email.
 
 =back
 
-Returns: unescaped version of $text (e.g., the entity &quot; will be
-replaced by the character '"')
-
-It may seem silly to have these html_ methods which currently just
-call the method of an external module, but we might wish to do more in
-the future (for example, screen out javascript>. This way, we have a
-central place to change it.
-
 =head1 TO DO
 
 Nothing known.
