@@ -1,6 +1,6 @@
 package OpenInteract::SQLInstall::User;
 
-# $Id: User.pm,v 1.4 2001/08/12 14:45:42 lachoy Exp $
+# $Id: User.pm,v 1.5 2001/10/17 04:47:08 lachoy Exp $
 
 use strict;
 use vars         qw( %HANDLERS );
@@ -35,7 +35,7 @@ sub create_admin_user {
                    name   => 'create_admin_user',
                    ok     => 1 };
     my $CONFIG = $R->CONFIG;
-    my $user = $R->user->new({ email      => $CONFIG->{admin_email},
+    my $user = $R->user->new({ email      => $CONFIG->{mail}{admin_email} || $CONFIG->{admin_email},
                                login_name => 'superuser',
                                first_name => 'Super',
                                last_name  => 'User',
