@@ -1,11 +1,11 @@
 package OpenInteract::User;
 
-# $Id: User.pm,v 1.5 2001/09/14 20:50:25 lachoy Exp $
+# $Id: User.pm,v 1.7 2001/11/28 13:04:02 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level :scope );
 
-$OpenInteract::User::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::User::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::User::crypt_password = undef;
 
 
@@ -86,6 +86,18 @@ sub check_password {
     return ( $check_pw eq $exist_pw );
 }
 
+
+sub is_in_group {
+    my ( $self, $group_spec ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $check_group_id = ( ref $group_spec )
+                           ? $group_spec->id : $group_spec;
+    foreach my $group ( @{ $R->{auth}{group} } ) {
+        return 1 if ( $group->id == $check_group_id );
+    }
+    return undef;
+}
+
 1;
 
 __END__
@@ -104,9 +116,17 @@ OpenInteract::User - Create and manipulate users.
   # Increment the user's login total
   $user->increment_login();
   print "Username: $user->{username}\n";
-  
+
+  # See if the user is in a particular group
+  if ( $user->is_in_group( $group ) ) {
+     print "Enter!";
+  }
+
+
 =head1 DESCRIPTION
 
+Basic methods for user objects
+
 =head1 METHODS
 
 B<full_name()>
@@ -124,6 +144,13 @@ B<check_password( $pw )>
 Return a 1 if the password matches what is in the database, a 0 if
 not.
 
+B<is_in_group( $group | $group_id )>
+
+Ask a user object if it belongs to a particular group. You can pass
+either a group object or its ID.
+
+Returns true if the user is in the group, false, if not.
+
 =head1 TO DO
 
 =head1 BUGS
