@@ -1,6 +1,6 @@
 CREATE TABLE theme_prop (
  themeprop_id  %%INCREMENT%%,
- theme_id      int not null,
+ theme_id      %%INCREMENT_TYPE%% not null,
  prop          varchar(30) not null,
  value         text null,
  description   text null,
